package page_votes

import (
	"code.electrolab.fr/it/vote.electrolab.fr/application"
	"context"
	"crypto/sha256"
	"database/sql"
	"encoding/hex"
	"html/template"
	"log"
	"net/http"
)

const (
	FORM_VOTER_PRIVATE_TOKEN = "private_token"
)

var (
	templateIndex     = template.Must(template.New("index").Parse(TEMPLATE_INDEX_STR))
	templateForbidden = template.Must(template.New("forbidden").Parse(TEMPLATE_FORBIDDEN_STR))
)

func RegisterRoutes(mux *http.ServeMux, app *application.App) {
	mux.Handle("/votes", application.NewAppHandler(app, handleGetVotes))
}

func handleGetVotes(app *application.App, ctx context.Context, w http.ResponseWriter, r *http.Request) {
	var (
		err               error
		templateIndexVars = new(TemplateIndexVars)
		privateToken      = r.FormValue(FORM_VOTER_PRIVATE_TOKEN)
		privateTokenSha   = sha256.Sum256([]byte(privateToken))
		publicToken       = hex.EncodeToString(privateTokenSha[:])
	)

	err = app.DB.QueryRowContext(ctx, `SELECT fullname FROM voters WHERE public_token = $1`, publicToken).Scan(&templateIndexVars.VoterFullname)
	if err != nil {
		if err == sql.ErrNoRows {
			// Token is invalid
			w.WriteHeader(http.StatusForbidden)
			err := templateForbidden.Execute(w, nil)
			if err != nil {
				log.Printf("Template execution error: %s", err.Error())
			}
			return
		} else {
			// Query has an error
			log.Printf("Query error 1: %s", err.Error())
			w.WriteHeader(http.StatusInternalServerError)
			return
		}
	}

	// Token is valid, download the questions

	rows, err := app.DB.QueryContext(ctx, `SELECT name, sentence, vote_open FROM questions`)
	if err != nil {
		// Query has an error
		log.Printf("Query error 2: %s", err.Error())
		w.WriteHeader(http.StatusInternalServerError)
		return
	}
	defer rows.Close()

	for rows.Next() {
		var question TemplateIndexVarsQuestion

		err = rows.Scan(&question.Name, &question.Sentence, &question.VoteOpen)
		if err != nil {
			log.Printf("Query error 3: %s", err.Error())
			w.WriteHeader(http.StatusInternalServerError)
			return
		}

		templateIndexVars.Questions = append(templateIndexVars.Questions, question)
	}

	err = templateIndex.Execute(w, templateIndexVars)
	if err != nil {
		// Template has an error
		log.Printf("Template execution error: %s", err.Error())
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

}
